// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef MAILCOMMON_VERSION_H
#define MAILCOMMON_VERSION_H

#define MAILCOMMON_VERSION_STRING "6.6.41"
#define MAILCOMMON_VERSION_MAJOR 6
#define MAILCOMMON_VERSION_MINOR 6
#define MAILCOMMON_VERSION_PATCH 41
#define MAILCOMMON_VERSION ((6<<16)|(6<<8)|(41))

#endif
